@@ -54,11 +54,11 @@ class upconfig(object):
         self.set_config.write()
         conlog(f'{self.update_tag}   *   {name}  *   ', f"更新完成_{date} ")
 
-
-    def check_update(self, name):
+    def check_update(self, name, difference: int = 0):
         """
         检查今日是否更新
         :param name: 检查对象
+        :param difference: 时间对比基准点，默认为0（今日），如果为 difference=1 则代表：如果上次更新日期是前一天，则返回False，代表更新完成，不需要更新
         :return:
         """
         try:
@@ -73,7 +73,7 @@ class upconfig(object):
                 self.config.set(self.update_tag, f'{name}', getdate(1))
             self.config.write(open(self.updatePath, 'w', encoding='utf-8-sig'))
             value = self.config.get(self.update_tag, f'{name}')
-        if value == get_now_date():  # 更新日期为今日则停止更新
+        if value == getdate(difference):
             conlog(f'{name}', "今日已更新完成")
             return False
         else:
